@@ -8,7 +8,7 @@ function check_with_gcc() {
   rm -f config.cache
   make clean
   ./configure -C --enable-debug CC=gcc
-  local gcc_exceptions="-Wno-sign-compare"
+  local gcc_exceptions="-Wno-sign-compare -Wno-enum-int-mismatch"
   make -j -l${n_procs} --keep-going CFLAGS="-Werror -Wall -Wextra $gcc_exceptions"
 }
 
@@ -26,11 +26,14 @@ function check_with_cppcheck() {
   # cppcheck options:
   #   -I -- include paths
   #   -i -- ignored files/folders
+  #   --include=<file> -- force including a file, e.g. config.h
   # Identified issues are printed to stderr
   cppcheck --quiet -j${n_procs} --error-exitcode=1 ./ \
            --suppressions-list=tests/static-check/cppcheck_suppressions.txt \
+           --check-level=exhaustive \
+           --include=config.h \
            -I cf-serverd/ -I libpromises/ -I libcfnet/ -I libntech/libutils/ \
-           -i 3rdparty -i .lgtm -i libntech/.lgtm -i tests -i libpromises/cf3lex.c \
+           -i 3rdparty -i .github/codeql -i libntech/.lgtm -i tests -i libpromises/cf3lex.c \
            2>&1 1>/dev/null
 }
 
